basky
======

|Coverage Status|
|Build Status|

A lightweight, robust basket app for your Django project.

Based on `django-ccbasket <https://github.com/designcc/django-ccbasket>`__ but has been updated to work with Django 1.6.

The `basky documentation is online <https://django-basky.readthedocs.org/en/latest/index.html>`__, but you may find parts
that refer to ccbasket (basky's previous incarnation), like baskey it is a work in progress.


|Bitdeli Badge|


.. |Bitdeli Badge| image:: https://d2weczhvl823v0.cloudfront.net/jamiecurle/django-basky/trend.png
.. |Coverage Status| image:: https://coveralls.io/repos/jamiecurle/django-basky/badge.png?branch=develop
.. |Build Status| image::  https://jenkins.curle.io/buildStatus/icon?job=django-basky-test-django-1.5.5
